@@ -1,4 +1,16 @@
 from abc import ABC, abstractmethod
+from typing import Optional
+
+
+class FilesystemFactory(ABC):
+
+    @abstractmethod
+    def create_local_filesystem(self) -> 'Filesystem':
+        pass
+
+    @abstractmethod
+    def create_ssh_filesystem(self) -> 'Filesystem':
+        pass
 
 
 class Filesystem(ABC):
@@ -7,7 +19,7 @@ class Filesystem(ABC):
     """
 
     @abstractmethod
-    def copy(self, source: str, target: str, overwrite: bool = False, filesystem: 'Filesystem' = None) -> None:
+    def copy(self, source: str, target: str, overwrite: bool = False, filesystem: Optional['Filesystem'] = None) -> None:
         """Copies the `source` file to the `target` location. Can transfer between filesystems if `filesystem` argument is specified
 
         Args:
