@@ -1,13 +1,16 @@
 from dataclasses import dataclass, field
-from typing import List
+from enum import Enum, auto
+from typing import List, Union
 
 from hpcrocket.core.environmentpreparation import CopyInstruction
-from hpcrocket.ssh.sshexecutor import ConnectionData
+from hpcrocket.ssh.connectiondata import ConnectionData
+
+
+Options = Union['LaunchOptions', 'JobBasedOptions']
 
 
 @dataclass
 class LaunchOptions:
-
     sbatch: str
     connection: ConnectionData
     proxyjumps: List[ConnectionData] = field(default_factory=lambda: [])
@@ -15,3 +18,17 @@ class LaunchOptions:
     clean_files: List[str] = field(default_factory=lambda: [])
     collect_files: List[CopyInstruction] = field(default_factory=lambda: [])
     poll_interval: int = 5
+    watch: bool = False
+
+
+@dataclass
+class JobBasedOptions:
+
+    class Action(Enum):
+        watch = auto()
+        status = auto()
+
+    jobid: str
+    action: Action
+    connection: ConnectionData
+    proxyjumps: List[ConnectionData] = field(default_factory=lambda: [])
